import { SUPABASE_URL, SUPABASE_ANON_KEY } from "./config.js";

// Initialize the Supabase client
const supabase = window.supabase.createClient(SUPABASE_URL, SUPABASE_ANON_KEY);

// Function to close the popup
function closePopup() {
  window.close();
}

document.addEventListener("DOMContentLoaded", async function () {
  const saveButton = document.getElementById("saveButton");
  const statusDiv = document.getElementById("status");
  let id = null;

  // Add click event listener to close popup when clicking outside
  document.addEventListener('click', (event) => {
    // Check if the click is outside the popup
    const popup = document.body;
    if (!popup.contains(event.target)) {
      closePopup();
    }
  });

  // Get the auth token from your Next.js app's cookies
  chrome.cookies.get(
    {
      url: "https://www.joinparcel.com",
      name: "parcel-chrome-session-data",
    },
    async function (cookie) {
      if (cookie) {
        try {
          // Set the auth session properly with both access and refresh tokens
          const {
            data: { session },
            error: sessionError,
          } = await supabase.auth.setSession({
            access_token: JSON.parse(cookie.value).access_token,
            refresh_token: JSON.parse(cookie.value).refresh_token,
          });

          if (sessionError) throw sessionError;

          // Get the user ID from the session
          id = session.user.id;
          saveButton.disabled = false;
          saveButton.style.display = "block";
        } catch (error) {
          // statusDiv.textContent = `Authentication error: ${error.message}`;
          statusDiv.textContent = "Please login to Parcel first.";
          saveButton.disabled = true;
        }
      } else {
        statusDiv.textContent = "Please login to Parcel first.";
        saveButton.disabled = true;
      } 
    }
  );

  saveButton.addEventListener("click", async () => {
    try {
      statusDiv.textContent = "Now Saving...";
      saveButton.disabled = true;

      // Get description from content script
      // Get current tab
      const [tab] = await chrome.tabs.query({
        active: true,
        currentWindow: true,
      });

      const pageDetails = await chrome.scripting.executeScript({
        target: { tabId: tab.id },
        func: () => {
          return {
            url: window.location.href,
            title:
              document.querySelector("title")?.textContent?.trim() ||
              document.title?.trim() ||
              window.location.hostname,
            description:
              document.querySelector('meta[name="description"]')?.content ||
              document.querySelector('meta[name="Description"]')?.content ||
              "No Description Found",
          };
        },
      });

      // Insert data into your Supabase table
      const { data, error } = await supabase.from("bookmarks").insert([
        {
          url: pageDetails[0].result.url,
          title: pageDetails[0].result.title,
          description: pageDetails[0].result.description,
          user_id: id,
        },
      ]);

      if (error) throw error;

      statusDiv.textContent = "Saved.";
    } catch (error) {
      statusDiv.textContent = `Error: ${error.message}`;
    } finally {
      saveButton.disabled = false;
    }
  });
});
